"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.onPostBuild = exports.onPreBootstrap = exports.pluginOptionsSchema = void 0;

var _path = _interopRequireDefault(require("path"));

var _fsExtra = require("fs-extra");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const pluginOptionsSchema = ({
  Joi
}) => {
  return Joi.object({
    persistentDir: Joi.string().required().description("Directory where persistent cache will be stored."),
    pluginNames: Joi.array().items(Joi.string()).required().description("Names of plugins to persist."),
    enabled: Joi.boolean().required().description("Set to false to prevent persisting, allows you to clean the persistent cache.")
  });
};

exports.pluginOptionsSchema = pluginOptionsSchema;

const getPaths = (persistentDir, rootDir, pluginName) => {
  return {
    pluginPath: _path.default.join(rootDir, ".cache", "caches", pluginName),
    persistentPath: _path.default.join(persistentDir, pluginName)
  };
};

const onPreBootstrap = async function ({
  store,
  reporter
}, {
  persistentDir,
  pluginNames,
  enabled,
  remove
}) {
  if (!enabled) {
    return;
  }

  const rootDir = store.getState().program.directory;
  const task = reporter.createProgress(`plugin-persist-cache: `, pluginNames.length, 0);
  task.start();

  for (const pluginName of pluginNames) {
    task.setStatus(`Restoring cache for ${pluginName}`);
    const {
      pluginPath,
      persistentPath
    } = getPaths(persistentDir, rootDir, pluginName);
    await (0, _fsExtra.ensureDir)(pluginPath);
    await (0, _fsExtra.ensureDir)(persistentPath);
    await (0, _fsExtra.copy)(persistentPath, pluginPath);
    task.tick(1);
  }

  task.setStatus(`Restored cache for ${pluginNames.length} plugins`);
  task.done();
};

exports.onPreBootstrap = onPreBootstrap;

const onPostBuild = async function ({
  store,
  reporter
}, {
  persistentDir,
  pluginNames,
  enabled
}) {
  if (!enabled) {
    return;
  }

  const rootDir = store.getState().program.directory;
  const task = reporter.createProgress(`plugin-persist-cache: `, pluginNames.length, 0);
  task.start();

  for (const pluginName of pluginNames) {
    task.setStatus(`Saving cache for ${pluginName}`);
    const {
      pluginPath,
      persistentPath
    } = getPaths(persistentDir, rootDir, pluginName);
    await (0, _fsExtra.ensureDir)(pluginPath);
    await (0, _fsExtra.ensureDir)(persistentPath);
    console.log(`copy${pluginPath}, ${persistentPath});`);
    await (0, _fsExtra.copy)(pluginPath, persistentPath);
    task.tick(1);
  }

  task.setStatus(`Saved cache for ${pluginNames.length} plugins`);
  task.done();
};

exports.onPostBuild = onPostBuild;
//# sourceMappingURL=gatsby-node.js.map